
Name:          marisa
Version:       0.2.6
Release:    1%{?dist}
Summary:       Static and spece-efficient trie data structure library

License:       BSD-2-Clause OR LGPL-2.1-or-later
URL:  https://github.com/s-yata/marisa-trie
Source0: https://github.com/s-yata/marisa-trie/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildRequires: autoconf, automake, libtool
BuildRequires: make
BuildRequires: gcc
BuildRequires: gcc-c++
BuildRequires: swig
BuildRequires: perl-devel
BuildRequires: perl-generators
BuildRequires: python3-devel
BuildRequires: python3-setuptools
BuildRequires: ruby-devel

%description
Matching Algorithm with Recursively Implemented StorAge (MARISA) is a
static and space-efficient trie data structure. And libmarisa is a C++
library to provide an implementation of MARISA. Also, the package of
libmarisa contains a set of command line tools for building and
operating a MARISA-based dictionary.

A MARISA-based dictionary supports not only lookup but also reverse
lookup, common prefix search and predictive search.


%package devel
Summary:       Development files for %{name}
Requires:      %{name} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package tools
Summary:       Tools for %{name}
Requires:      %{name} = %{version}-%{release}

%description tools
The %{name}-tools package contains tools for developing applications
that use %{name}.


%package perl
Summary:       Perl language binding for marisa
Requires:      %{name} = %{version}-%{release}

%description perl
Perl language binding for marisa


%package -n python3-%{name}
Summary:       Python 3 language binding for marisa
Requires:      %{name} = %{version}-%{release}

%description -n python3-%{name}
Python 3 language binding for marisa


%package ruby
Summary: Ruby language binding for marisa
Requires:      %{name} = %{version}-%{release}
Requires:      ruby(release)

%description ruby
Ruby language binding for groonga


%prep
%autosetup -n %{name}-trie-%{version}


%build
%set_build_flags

autoreconf -i
%configure --disable-static
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
%{make_build}

pushd bindings/perl
%{__perl} Makefile.PL INC="-I%{_builddir}/%{name}-trie-%{version}/include" LIBS="-L%{_builddir}/%{name}-trie-%{version}/lib/%{name}/.libs -lmarisa" INSTALLDIRS=vendor
%{make_build}
popd

%{make_build} --directory=bindings swig-python

pushd bindings/python

%{__python3} setup.py build_ext --include-dirs="%{_builddir}/%{name}-trie-%{version}/include" --library-dirs="%{_builddir}/%{name}-trie-%{version}/lib/%{name}/.libs"
%py3_build
popd

pushd bindings
%{make_build} swig-ruby
popd

pushd bindings/ruby
ruby extconf.rb --with-opt-include="%{_builddir}/%{name}-trie-%{version}/include" --with-opt-lib="%{_builddir}/%{name}-trie-%{version}/lib/%{name}/.libs" --vendor
%{make_build}
popd

%install
%make_install INSTALL="install -p"

pushd bindings/perl
%make_install INSTALL="install -p"
rm -f %{buildroot}%{perl_vendorarch}/auto/marisa/.packlist
%{_fixperms} -c %{buildroot}%{perl_vendorarch}/*
popd

pushd bindings/python
%py3_install
rm -rf %{buildroot}/%{python3_sitearch}/marisa-0.0.0-py%{python3_version}.egg-info
popd

pushd bindings/ruby
%make_install INSTALL="install -p"
popd

find %{buildroot} -name '*.la' -exec rm -f {} ';'
find %{buildroot} -name 'perllocal.pod' -exec rm -f {} ';'
rm -f %{buildroot}%{perl_vendorarch}/sample.pl


%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc docs/style.css AUTHORS README.md docs/readme.en.html
%lang(ja) %doc docs/readme.ja.html
%license COPYING.md
%{_libdir}/libmarisa.so.*

%files devel
%{_includedir}/marisa*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files tools
%{_bindir}/marisa-benchmark
%{_bindir}/marisa-build
%{_bindir}/marisa-common-prefix-search
%{_bindir}/marisa-dump
%{_bindir}/marisa-lookup
%{_bindir}/marisa-predictive-search
%{_bindir}/marisa-reverse-lookup

%files perl
%{perl_vendorarch}/marisa.pm
%{perl_vendorarch}/auto/marisa
%{perl_vendorarch}/benchmark.pl

%files -n python3-%{name}
%{python3_sitearch}/__pycache__/marisa*
%{python3_sitearch}/_marisa*.so
%{python3_sitearch}/marisa.py

%files ruby
%{ruby_vendorarchdir}/marisa.so

%changelog
* Wed Jul 24 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.2.6-1
- initial build
